/* gok-page-keyboard.h
*
* Copyright 2004 Sun Microsystems, Inc.,
* Copyright 2004 University Of Toronto
* Copyright 2009 Gerd Kohlberger <gerdko gmail com>
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Library General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Library General Public License for more details.
*
* You should have received a copy of the GNU Library General Public
* License along with this library; if not, write to the
* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
* Boston, MA 02111-1307, USA.
*/

gboolean gok_page_keyboard_initialize (void);
void gok_page_keyboard_refresh (void);
gboolean gok_page_keyboard_apply (void);
gboolean gok_page_keyboard_revert (void);
void gok_page_keyboard_backup (void);
void gok_page_keyboard_update_custom_compose_from_control (void);
